/**
  *  \file client/tiles/planetheader.cc
  *
  *  (c) 2001-2022 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/tiles/planetheader.h"
#include "util/nls.h"
#include "game/planet.h"
#include "cpluslib/format.h"
#include "game/tables.h"
#include "game/config.h"
#include "resmgr/resid.h"

WPlanetScreenHeaderTile::WPlanetScreenHeaderTile(GObjectSelection& selection, bool forTask)
    : WControlScreenHeaderTile(selection, forTask ? bCScr : bAuto + bAdd + bSend, IntExecutionContext::pkPlanetTask),
      forTask(forTask)
{ }

string_t
WPlanetScreenHeaderTile::getTitle()
{
    return getCurrentObject()->getName(GObject::PlainName);
}

string_t
WPlanetScreenHeaderTile::getSubtitle()
{
    string_t result;
    if (GPlanet* p = dynamic_cast<GPlanet*>(getCurrentObject())) {
        int16 level = p->unit_scores.getScore(planet_score_definitions.lookupScore(ScoreId_ExpLevel));
        // C2 B0 = U+00B0 = DEGREE SIGN
        const char* fmt = (level >= 0
                           ? _("(Id #%d, %s - %d" "\xC2\xB0" "\x46, %s)")
                           : _("(Id #%d, %s - %d" "\xC2\xB0" "\x46)"));
        result = format(fmt,
                        p->getId(),
                        getTemperatureName(p->getTemperature()),
                        p->getTemperature(),
                        getExperienceLevelName(level));
    }
    return result;
}

ResId
WPlanetScreenHeaderTile::getPictureId()
{
    ResId result;
    if (GPlanet* p = dynamic_cast<GPlanet*>(getCurrentObject()))
        result = ResId(res::planet, p->getTemperature(), p->getId());
    return result;
}

int
WPlanetScreenHeaderTile::getNumMessages()
{
    int result = 0;
    if (!forTask) {
        if (GPlanet* p = dynamic_cast<GPlanet*>(getCurrentObject())) {
            result = p->getAssociatedMessages().size();
        }
    }
    return result;
}
