/**
  *  \file game/inbox.h
  *  \brief Subspace Messages: Inbox
  *
  *  (c) 2001-2022 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_INBOX_H
#define PCC_V2_GAME_INBOX_H

#include "game/msg.h"
#include "cpluslib/ptrvector.h"

class Stream;

/** Standard inbox. The idea is to allow having a single inbox even
    when there are multiple results, where all messages are listed and
    probably duplicates removed.

    When looking at a message, we still need to know who originally
    got the message, to know whom "we are scanning our mines" refers
    to. We can therefore associate a player number with each message.
    Otherwise, this number is not interpreted in any way by GInbox.

    This class also includes a method to load a standard inbox, which
    works for all inbox storage so far (RST, MDATA, VPA DB). */
class GInbox : public GMessagebox {
    struct Message;
    ptr_vector<Message> messages;

    void addMessage(string_t str, int receiver);
 public:
    GInbox();
    ~GInbox();
    int      getCount();
    string_t getText(int index);
    string_t getHeading(int index);
    int      getReceiver(int index) const;

    void sort();

    void loadInbox(Stream& str, int receiver);
};

#endif
