/**
  *  \file game/objobserve.cc
  *  \brief Class GObjectSelectionObserver
  *
  *  (c) 2001-2022 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "game/objobserve.h"
#include "game/objsel.h"
#include "game/obj.h"

/** Constructor. */
GObjectSelectionObserver::GObjectSelectionObserver(GObjectSelection& selection)
    : selection(selection),
      conn_current_changed(),
      conn_obj_changed()
{
    attachSelection();
    attachObject();
}

GObjectSelectionObserver::~GObjectSelectionObserver()
{ }

void
GObjectSelectionObserver::onCurrentChanged()
{
    attachObject();
    onObjectChanged();
}

void
GObjectSelectionObserver::attachObject()
{
    if (GObject* obj = getCurrentObject()) {
        conn_obj_changed = obj->sig_changed.add(this, &GObjectSelectionObserver::onObjectChanged);
    } else {
        conn_obj_changed.disconnect();
    }
}

void
GObjectSelectionObserver::attachSelection()
{
    conn_current_changed = selection.sig_current_changed.add(this, &GObjectSelectionObserver::onCurrentChanged);
}
