/**
  *  \file int/parseexpr.h
  *  \brief Interpreter: Expression Parser
  *
  *  (c) 2001-2022 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_INT_PARSEEXPR_H
#define PCC_V2_INT_PARSEEXPR_H

#include "cpluslib/ptrvector.h"
#include "int/expr.h"
#include "int/lex.h"

/** Expression Parser. This parses an expression, tokenized by an IntTokenizer,
    into a tree of IntExprNode's.

    To support exception safety, this collects expression trees on a stack which
    is cleaned up in the destructor. During parsing, several partial trees exist
    on the stack. When parsing finishes, only one tree (the result) remains, which
    refers to all former partial trees. */
class IntExpressionParser {
 public:
    IntExpressionParser(IntTokenizer& tok);

    IntExprNode* parse();
    IntExprNode* parseNA();

 private:
    void parseSequence();
    void parseAssignment();
    void parseOr();
    void parseAnd();
    void parseNot();
    void parseComparison();
    void parseConcat();
    void parseAdd();
    void parseMult();
    void parseNeg();
    void parsePow();
    void parsePrimary();
    void parseArglist(IntFunctionCallNode* fcn);

    void makeUnary(IntSimpleRValueExprNode* n);
    void makeBinary(IntSimpleRValueExprNode* n);
    void makeTernary(IntSimpleRValueExprNode* n);

    IntTokenizer& tok;
    ptr_vector<IntExprNode> stack;
};

#endif
