/**
  *  \file ui/skin.h
  *  \brief Skinning and Color Scheme Management
  *
  *  (c) 2001-2022 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_UI_SKIN_H
#define PCC_V2_UI_SKIN_H

#include "cpluslib/object.h"
#include "gfx/gfx.h"
#include "gfx/gfxcontext.h"

//
//  Color Management
//

/** Logical color names. */
struct UIColor {
    enum Color {
        tc_Static,              ///< static text
        tc_Green,               ///< green (variable)
        tc_Yellow,              ///< yellow (variable)
        tc_Red,                 ///< red (variable)
        tc_White,               ///< white (headings)
        tc_Contrast,            ///< some contrast against background (frame)
        tc_Input,               ///< input lines (blue)
        tc_Blue,                ///< blue for shaded list items
        tc_Faded,               ///< gray for faded list items
        tc_Heading,             ///< headings
        tc_Selection,           ///< selection marker (yellow/green)
        tc_InvStatic,           ///< opposite of static to build contrasts.
        tc_Background,          ///< background color approximation
        tc_Link,                ///< Link text color (on background).
        tc_LinkShade,           ///< Link shade (background to tc_Link).
        tc_LinkFocus            ///< Link focus (background to tc_Link).
    };
    enum { COUNT = tc_LinkFocus+1 };
};

/** A set of colors. */
struct UIColorSet {
    uint8 table[UIColor::COUNT];
    // This dummy element is to allow recognition of initialisation
    // errors. You can write 'UIColorSet x = { a,b,c, {} }' and the
    // compiler will tell you when you have too few colors.
    struct dummy { } dummy;

    uint8 operator[](UIColor::Color i) const { return table[i]; }
};
extern UIColorSet GRAY_COLOR_SET, DARK_COLOR_SET, BLACK_COLOR_SET, BRIGHT_GRAY_COLOR_SET;

class UISkin : public GfxColorScheme {
 public:
    typedef UIColor::Color Color;

    /** Constructor. */
    UISkin(const UIColorSet& cs)
        : cs(cs)
        { }

    // UISkin:
    const UIColorSet& getColors() const
        { return cs; }

    // GfxColorScheme:
    virtual void drawBackground(GfxContext& ctx, GfxRect area);
    virtual uint32_t getColor(uint32_t color);

    static UISkin& getDefaultSkin();
 private:
    const UIColorSet& cs;
};

#endif
